import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { ExecuteScheduledQueryRequest } from "../models/models_0";
import { ServiceInputTypes, ServiceOutputTypes, TimestreamQueryClientResolvedConfig } from "../TimestreamQueryClient";
export interface ExecuteScheduledQueryCommandInput extends ExecuteScheduledQueryRequest {
}
export interface ExecuteScheduledQueryCommandOutput extends __MetadataBearer {
}
/**
 * <p> You can use this API to run a scheduled query manually. </p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { TimestreamQueryClient, ExecuteScheduledQueryCommand } from "@aws-sdk/client-timestream-query"; // ES Modules import
 * // const { TimestreamQueryClient, ExecuteScheduledQueryCommand } = require("@aws-sdk/client-timestream-query"); // CommonJS import
 * const client = new TimestreamQueryClient(config);
 * const command = new ExecuteScheduledQueryCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link ExecuteScheduledQueryCommandInput} for command's `input` shape.
 * @see {@link ExecuteScheduledQueryCommandOutput} for command's `response` shape.
 * @see {@link TimestreamQueryClientResolvedConfig | config} for TimestreamQueryClient's `config` shape.
 *
 */
export declare class ExecuteScheduledQueryCommand extends $Command<ExecuteScheduledQueryCommandInput, ExecuteScheduledQueryCommandOutput, TimestreamQueryClientResolvedConfig> {
    readonly input: ExecuteScheduledQueryCommandInput;
    constructor(input: ExecuteScheduledQueryCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: TimestreamQueryClientResolvedConfig, options?: __HttpHandlerOptions): Handler<ExecuteScheduledQueryCommandInput, ExecuteScheduledQueryCommandOutput>;
    private serialize;
    private deserialize;
}
