import { ExceptionOptionType as __ExceptionOptionType } from "@aws-sdk/smithy-client";
import { TimestreamQueryServiceException as __BaseException } from "./TimestreamQueryServiceException";

export declare class AccessDeniedException extends __BaseException {
    readonly name: "AccessDeniedException";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<AccessDeniedException, __BaseException>);
}
export interface CancelQueryRequest {
    
    QueryId: string | undefined;
}
export declare namespace CancelQueryRequest {
    
    const filterSensitiveLog: (obj: CancelQueryRequest) => any;
}
export interface CancelQueryResponse {
    
    CancellationMessage?: string;
}
export declare namespace CancelQueryResponse {
    
    const filterSensitiveLog: (obj: CancelQueryResponse) => any;
}

export declare class InternalServerException extends __BaseException {
    readonly name: "InternalServerException";
    readonly $fault: "server";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<InternalServerException, __BaseException>);
}

export declare class InvalidEndpointException extends __BaseException {
    readonly name: "InvalidEndpointException";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<InvalidEndpointException, __BaseException>);
}

export declare class ThrottlingException extends __BaseException {
    readonly name: "ThrottlingException";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<ThrottlingException, __BaseException>);
}

export declare class ValidationException extends __BaseException {
    readonly name: "ValidationException";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<ValidationException, __BaseException>);
}
export declare enum ScalarType {
    BIGINT = "BIGINT",
    BOOLEAN = "BOOLEAN",
    DATE = "DATE",
    DOUBLE = "DOUBLE",
    INTEGER = "INTEGER",
    INTERVAL_DAY_TO_SECOND = "INTERVAL_DAY_TO_SECOND",
    INTERVAL_YEAR_TO_MONTH = "INTERVAL_YEAR_TO_MONTH",
    TIME = "TIME",
    TIMESTAMP = "TIMESTAMP",
    UNKNOWN = "UNKNOWN",
    VARCHAR = "VARCHAR"
}

export declare class ConflictException extends __BaseException {
    readonly name: "ConflictException";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<ConflictException, __BaseException>);
}
export declare enum S3EncryptionOption {
    SSE_KMS = "SSE_KMS",
    SSE_S3 = "SSE_S3"
}

export interface S3Configuration {
    
    BucketName: string | undefined;
    
    ObjectKeyPrefix?: string;
    
    EncryptionOption?: S3EncryptionOption | string;
}
export declare namespace S3Configuration {
    
    const filterSensitiveLog: (obj: S3Configuration) => any;
}

export interface ErrorReportConfiguration {
    
    S3Configuration: S3Configuration | undefined;
}
export declare namespace ErrorReportConfiguration {
    
    const filterSensitiveLog: (obj: ErrorReportConfiguration) => any;
}

export interface SnsConfiguration {
    
    TopicArn: string | undefined;
}
export declare namespace SnsConfiguration {
    
    const filterSensitiveLog: (obj: SnsConfiguration) => any;
}

export interface NotificationConfiguration {
    
    SnsConfiguration: SnsConfiguration | undefined;
}
export declare namespace NotificationConfiguration {
    
    const filterSensitiveLog: (obj: NotificationConfiguration) => any;
}

export interface ScheduleConfiguration {
    
    ScheduleExpression: string | undefined;
}
export declare namespace ScheduleConfiguration {
    
    const filterSensitiveLog: (obj: ScheduleConfiguration) => any;
}

export interface Tag {
    
    Key: string | undefined;
    
    Value: string | undefined;
}
export declare namespace Tag {
    
    const filterSensitiveLog: (obj: Tag) => any;
}
export declare enum DimensionValueType {
    VARCHAR = "VARCHAR"
}

export interface DimensionMapping {
    
    Name: string | undefined;
    
    DimensionValueType: DimensionValueType | string | undefined;
}
export declare namespace DimensionMapping {
    
    const filterSensitiveLog: (obj: DimensionMapping) => any;
}
export declare enum MeasureValueType {
    BIGINT = "BIGINT",
    BOOLEAN = "BOOLEAN",
    DOUBLE = "DOUBLE",
    MULTI = "MULTI",
    VARCHAR = "VARCHAR"
}
export declare enum ScalarMeasureValueType {
    BIGINT = "BIGINT",
    BOOLEAN = "BOOLEAN",
    DOUBLE = "DOUBLE",
    TIMESTAMP = "TIMESTAMP",
    VARCHAR = "VARCHAR"
}

export interface MultiMeasureAttributeMapping {
    
    SourceColumn: string | undefined;
    
    TargetMultiMeasureAttributeName?: string;
    
    MeasureValueType: ScalarMeasureValueType | string | undefined;
}
export declare namespace MultiMeasureAttributeMapping {
    
    const filterSensitiveLog: (obj: MultiMeasureAttributeMapping) => any;
}

export interface MixedMeasureMapping {
    
    MeasureName?: string;
    
    SourceColumn?: string;
    
    TargetMeasureName?: string;
    
    MeasureValueType: MeasureValueType | string | undefined;
    
    MultiMeasureAttributeMappings?: MultiMeasureAttributeMapping[];
}
export declare namespace MixedMeasureMapping {
    
    const filterSensitiveLog: (obj: MixedMeasureMapping) => any;
}

export interface MultiMeasureMappings {
    
    TargetMultiMeasureName?: string;
    
    MultiMeasureAttributeMappings: MultiMeasureAttributeMapping[] | undefined;
}
export declare namespace MultiMeasureMappings {
    
    const filterSensitiveLog: (obj: MultiMeasureMappings) => any;
}

export interface TimestreamConfiguration {
    
    DatabaseName: string | undefined;
    
    TableName: string | undefined;
    
    TimeColumn: string | undefined;
    
    DimensionMappings: DimensionMapping[] | undefined;
    
    MultiMeasureMappings?: MultiMeasureMappings;
    
    MixedMeasureMappings?: MixedMeasureMapping[];
    
    MeasureNameColumn?: string;
}
export declare namespace TimestreamConfiguration {
    
    const filterSensitiveLog: (obj: TimestreamConfiguration) => any;
}

export interface TargetConfiguration {
    
    TimestreamConfiguration: TimestreamConfiguration | undefined;
}
export declare namespace TargetConfiguration {
    
    const filterSensitiveLog: (obj: TargetConfiguration) => any;
}
export interface CreateScheduledQueryRequest {
    
    Name: string | undefined;
    
    QueryString: string | undefined;
    
    ScheduleConfiguration: ScheduleConfiguration | undefined;
    
    NotificationConfiguration: NotificationConfiguration | undefined;
    
    TargetConfiguration?: TargetConfiguration;
    
    ClientToken?: string;
    
    ScheduledQueryExecutionRoleArn: string | undefined;
    
    Tags?: Tag[];
    
    KmsKeyId?: string;
    
    ErrorReportConfiguration: ErrorReportConfiguration | undefined;
}
export declare namespace CreateScheduledQueryRequest {
    
    const filterSensitiveLog: (obj: CreateScheduledQueryRequest) => any;
}
export interface CreateScheduledQueryResponse {
    
    Arn: string | undefined;
}
export declare namespace CreateScheduledQueryResponse {
    
    const filterSensitiveLog: (obj: CreateScheduledQueryResponse) => any;
}

export declare class ServiceQuotaExceededException extends __BaseException {
    readonly name: "ServiceQuotaExceededException";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<ServiceQuotaExceededException, __BaseException>);
}
export interface DeleteScheduledQueryRequest {
    
    ScheduledQueryArn: string | undefined;
}
export declare namespace DeleteScheduledQueryRequest {
    
    const filterSensitiveLog: (obj: DeleteScheduledQueryRequest) => any;
}

export declare class ResourceNotFoundException extends __BaseException {
    readonly name: "ResourceNotFoundException";
    readonly $fault: "client";
    Message?: string;
    
    ScheduledQueryArn?: string;
    
    constructor(opts: __ExceptionOptionType<ResourceNotFoundException, __BaseException>);
}
export interface DescribeEndpointsRequest {
}
export declare namespace DescribeEndpointsRequest {
    
    const filterSensitiveLog: (obj: DescribeEndpointsRequest) => any;
}

export interface Endpoint {
    
    Address: string | undefined;
    
    CachePeriodInMinutes: number | undefined;
}
export declare namespace Endpoint {
    
    const filterSensitiveLog: (obj: Endpoint) => any;
}
export interface DescribeEndpointsResponse {
    
    Endpoints: Endpoint[] | undefined;
}
export declare namespace DescribeEndpointsResponse {
    
    const filterSensitiveLog: (obj: DescribeEndpointsResponse) => any;
}
export interface DescribeScheduledQueryRequest {
    
    ScheduledQueryArn: string | undefined;
}
export declare namespace DescribeScheduledQueryRequest {
    
    const filterSensitiveLog: (obj: DescribeScheduledQueryRequest) => any;
}

export interface S3ReportLocation {
    
    BucketName?: string;
    
    ObjectKey?: string;
}
export declare namespace S3ReportLocation {
    
    const filterSensitiveLog: (obj: S3ReportLocation) => any;
}

export interface ErrorReportLocation {
    
    S3ReportLocation?: S3ReportLocation;
}
export declare namespace ErrorReportLocation {
    
    const filterSensitiveLog: (obj: ErrorReportLocation) => any;
}

export interface ExecutionStats {
    
    ExecutionTimeInMillis?: number;
    
    DataWrites?: number;
    
    BytesMetered?: number;
    
    RecordsIngested?: number;
    
    QueryResultRows?: number;
}
export declare namespace ExecutionStats {
    
    const filterSensitiveLog: (obj: ExecutionStats) => any;
}
export declare enum ScheduledQueryRunStatus {
    AUTO_TRIGGER_FAILURE = "AUTO_TRIGGER_FAILURE",
    AUTO_TRIGGER_SUCCESS = "AUTO_TRIGGER_SUCCESS",
    MANUAL_TRIGGER_FAILURE = "MANUAL_TRIGGER_FAILURE",
    MANUAL_TRIGGER_SUCCESS = "MANUAL_TRIGGER_SUCCESS"
}

export interface ScheduledQueryRunSummary {
    
    InvocationTime?: Date;
    
    TriggerTime?: Date;
    
    RunStatus?: ScheduledQueryRunStatus | string;
    
    ExecutionStats?: ExecutionStats;
    
    ErrorReportLocation?: ErrorReportLocation;
    
    FailureReason?: string;
}
export declare namespace ScheduledQueryRunSummary {
    
    const filterSensitiveLog: (obj: ScheduledQueryRunSummary) => any;
}
export declare enum ScheduledQueryState {
    DISABLED = "DISABLED",
    ENABLED = "ENABLED"
}

export interface ScheduledQueryDescription {
    
    Arn: string | undefined;
    
    Name: string | undefined;
    
    QueryString: string | undefined;
    
    CreationTime?: Date;
    
    State: ScheduledQueryState | string | undefined;
    
    PreviousInvocationTime?: Date;
    
    NextInvocationTime?: Date;
    
    ScheduleConfiguration: ScheduleConfiguration | undefined;
    
    NotificationConfiguration: NotificationConfiguration | undefined;
    
    TargetConfiguration?: TargetConfiguration;
    
    ScheduledQueryExecutionRoleArn?: string;
    
    KmsKeyId?: string;
    
    ErrorReportConfiguration?: ErrorReportConfiguration;
    
    LastRunSummary?: ScheduledQueryRunSummary;
    
    RecentlyFailedRuns?: ScheduledQueryRunSummary[];
}
export declare namespace ScheduledQueryDescription {
    
    const filterSensitiveLog: (obj: ScheduledQueryDescription) => any;
}
export interface DescribeScheduledQueryResponse {
    
    ScheduledQuery: ScheduledQueryDescription | undefined;
}
export declare namespace DescribeScheduledQueryResponse {
    
    const filterSensitiveLog: (obj: DescribeScheduledQueryResponse) => any;
}
export interface ExecuteScheduledQueryRequest {
    
    ScheduledQueryArn: string | undefined;
    
    InvocationTime: Date | undefined;
    
    ClientToken?: string;
}
export declare namespace ExecuteScheduledQueryRequest {
    
    const filterSensitiveLog: (obj: ExecuteScheduledQueryRequest) => any;
}
export interface ListScheduledQueriesRequest {
    
    MaxResults?: number;
    
    NextToken?: string;
}
export declare namespace ListScheduledQueriesRequest {
    
    const filterSensitiveLog: (obj: ListScheduledQueriesRequest) => any;
}

export interface TimestreamDestination {
    
    DatabaseName?: string;
    
    TableName?: string;
}
export declare namespace TimestreamDestination {
    
    const filterSensitiveLog: (obj: TimestreamDestination) => any;
}

export interface TargetDestination {
    
    TimestreamDestination?: TimestreamDestination;
}
export declare namespace TargetDestination {
    
    const filterSensitiveLog: (obj: TargetDestination) => any;
}

export interface ScheduledQuery {
    
    Arn: string | undefined;
    
    Name: string | undefined;
    
    CreationTime?: Date;
    
    State: ScheduledQueryState | string | undefined;
    
    PreviousInvocationTime?: Date;
    
    NextInvocationTime?: Date;
    
    ErrorReportConfiguration?: ErrorReportConfiguration;
    
    TargetDestination?: TargetDestination;
    
    LastRunStatus?: ScheduledQueryRunStatus | string;
}
export declare namespace ScheduledQuery {
    
    const filterSensitiveLog: (obj: ScheduledQuery) => any;
}
export interface ListScheduledQueriesResponse {
    
    ScheduledQueries: ScheduledQuery[] | undefined;
    
    NextToken?: string;
}
export declare namespace ListScheduledQueriesResponse {
    
    const filterSensitiveLog: (obj: ListScheduledQueriesResponse) => any;
}
export interface ListTagsForResourceRequest {
    
    ResourceARN: string | undefined;
    
    MaxResults?: number;
    
    NextToken?: string;
}
export declare namespace ListTagsForResourceRequest {
    
    const filterSensitiveLog: (obj: ListTagsForResourceRequest) => any;
}
export interface ListTagsForResourceResponse {
    
    Tags: Tag[] | undefined;
    
    NextToken?: string;
}
export declare namespace ListTagsForResourceResponse {
    
    const filterSensitiveLog: (obj: ListTagsForResourceResponse) => any;
}
export interface PrepareQueryRequest {
    
    QueryString: string | undefined;
    
    ValidateOnly?: boolean;
}
export declare namespace PrepareQueryRequest {
    
    const filterSensitiveLog: (obj: PrepareQueryRequest) => any;
}

export declare class QueryExecutionException extends __BaseException {
    readonly name: "QueryExecutionException";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<QueryExecutionException, __BaseException>);
}
export interface QueryRequest {
    
    QueryString: string | undefined;
    
    ClientToken?: string;
    
    NextToken?: string;
    
    MaxRows?: number;
}
export declare namespace QueryRequest {
    
    const filterSensitiveLog: (obj: QueryRequest) => any;
}

export interface QueryStatus {
    
    ProgressPercentage?: number;
    
    CumulativeBytesScanned?: number;
    
    CumulativeBytesMetered?: number;
}
export declare namespace QueryStatus {
    
    const filterSensitiveLog: (obj: QueryStatus) => any;
}
export interface TagResourceRequest {
    
    ResourceARN: string | undefined;
    
    Tags: Tag[] | undefined;
}
export declare namespace TagResourceRequest {
    
    const filterSensitiveLog: (obj: TagResourceRequest) => any;
}
export interface TagResourceResponse {
}
export declare namespace TagResourceResponse {
    
    const filterSensitiveLog: (obj: TagResourceResponse) => any;
}
export interface UntagResourceRequest {
    
    ResourceARN: string | undefined;
    
    TagKeys: string[] | undefined;
}
export declare namespace UntagResourceRequest {
    
    const filterSensitiveLog: (obj: UntagResourceRequest) => any;
}
export interface UntagResourceResponse {
}
export declare namespace UntagResourceResponse {
    
    const filterSensitiveLog: (obj: UntagResourceResponse) => any;
}
export interface UpdateScheduledQueryRequest {
    
    ScheduledQueryArn: string | undefined;
    
    State: ScheduledQueryState | string | undefined;
}
export declare namespace UpdateScheduledQueryRequest {
    
    const filterSensitiveLog: (obj: UpdateScheduledQueryRequest) => any;
}

export interface ColumnInfo {
    
    Name?: string;
    
    Type: Type | undefined;
}
export declare namespace ColumnInfo {
    
    const filterSensitiveLog: (obj: ColumnInfo) => any;
}

export interface Type {
    
    ScalarType?: ScalarType | string;
    
    ArrayColumnInfo?: ColumnInfo;
    
    TimeSeriesMeasureValueColumnInfo?: ColumnInfo;
    
    RowColumnInfo?: ColumnInfo[];
}
export declare namespace Type {
    
    const filterSensitiveLog: (obj: Type) => any;
}

export interface Datum {
    
    ScalarValue?: string;
    
    TimeSeriesValue?: TimeSeriesDataPoint[];
    
    ArrayValue?: Datum[];
    
    RowValue?: Row;
    
    NullValue?: boolean;
}
export declare namespace Datum {
    
    const filterSensitiveLog: (obj: Datum) => any;
}

export interface ParameterMapping {
    
    Name: string | undefined;
    
    Type: Type | undefined;
}
export declare namespace ParameterMapping {
    
    const filterSensitiveLog: (obj: ParameterMapping) => any;
}

export interface SelectColumn {
    
    Name?: string;
    
    Type?: Type;
    
    DatabaseName?: string;
    
    TableName?: string;
    
    Aliased?: boolean;
}
export declare namespace SelectColumn {
    
    const filterSensitiveLog: (obj: SelectColumn) => any;
}

export interface TimeSeriesDataPoint {
    
    Time: string | undefined;
    
    Value: Datum | undefined;
}
export declare namespace TimeSeriesDataPoint {
    
    const filterSensitiveLog: (obj: TimeSeriesDataPoint) => any;
}

export interface Row {
    
    Data: Datum[] | undefined;
}
export declare namespace Row {
    
    const filterSensitiveLog: (obj: Row) => any;
}
export interface QueryResponse {
    
    QueryId: string | undefined;
    
    NextToken?: string;
    
    Rows: Row[] | undefined;
    
    ColumnInfo: ColumnInfo[] | undefined;
    
    QueryStatus?: QueryStatus;
}
export declare namespace QueryResponse {
    
    const filterSensitiveLog: (obj: QueryResponse) => any;
}
export interface PrepareQueryResponse {
    
    QueryString: string | undefined;
    
    Columns: SelectColumn[] | undefined;
    
    Parameters: ParameterMapping[] | undefined;
}
export declare namespace PrepareQueryResponse {
    
    const filterSensitiveLog: (obj: PrepareQueryResponse) => any;
}
